==> qjs-wrapper-v1.3.tar.gz: qjs-wrapper-v1.3/include/pubsub.h <==
#ifndef __PUBSUB_H__
#define __PUBSUB_H__

#include <open62541/server.h>
#include <open62541/plugin/log_stdout.h>

#include <quickjs/quickjs.h>

#define DLL_PUBLIC __attribute__ ((visibility ("default")))

#define countof(x) (sizeof(x) / sizeof((x)[0]))

#define DATA_SET_WRITER_ID 1
#define WRITER_GROUP_ID 1

#define MAX_MESSAGE_SIZE 1024

typedef struct {
    UA_UInt16 id;
    UA_UInt32 positionArrayId;
    UA_UInt32 speedArrayId;
    UA_Double latitude;
    UA_Double longitude;
    UA_Double altitudeAbs;
    UA_Double altitudeRel;
    UA_Float  yaw;
    UA_Float  speed;
    UA_Float  climbRate;
    char      message[MAX_MESSAGE_SIZE];
    UA_UInt32 messageId;
} JSDroneData;

typedef struct {
    char*       name;
    char*       typeName;
    UA_NodeId   typeNodeId;
    char*       description;
    void*       value;
    int         type;
    UA_Byte     builtInType;
    UA_Int32    valueRank;
    size_t      arrayDimensionsSize;
    UA_UInt32*  arrayDimensions;
    union {
        void*     (*getArray)(void);
        UA_String (*getString)(void);
    } getter;
} VariableData;

int runPubsub(UA_String *transportProfile,
              UA_NetworkAddressUrlDataType *networkAddressUrl,
              VariableData *variableArray, size_t nbVariable, 
              UA_UInt32 id, UA_UInt32 nbReader, UA_Duration interval,
              void (*init_node_id)(UA_UInt32 id, UA_UInt32 nb, UA_UInt32 magic),
              UA_UInt16 (*get_reader_id)(UA_UInt32 nb),
              VariableData (*get_value)(UA_String identifier),
              void (*update)(UA_UInt32 id, const UA_DataValue*, bool print),
              bool publish, UA_Boolean *running);

UA_String get_message(void);

UA_UInt16 get_drone_id(UA_UInt32 nb);

void init_node_id(UA_UInt32 id, UA_UInt32 nb, UA_UInt32 magic);

VariableData pubsub_get_value(UA_String identifier);

DLL_PUBLIC JSModuleDef *js_init_module(JSContext *ctx, const char *module_name);

#endif /* __PUBSUB_H__ */

==> qjs-wrapper-v2.0.tar.gz: qjs-wrapper-v2.0/include/pubsub.h <==
#ifndef __PUBSUB_H__
#define __PUBSUB_H__

#include <open62541/server.h>
#include <open62541/plugin/log_stdout.h>

#include <quickjs/quickjs.h>

#ifndef DLL_PUBLIC
#define DLL_PUBLIC __attribute__ ((visibility ("default")))
#endif

#define countof(x) (sizeof(x) / sizeof((x)[0]))

#define DATA_SET_WRITER_ID 1
#define WRITER_GROUP_ID 1

#define MAX_MESSAGE_SIZE 1024

typedef struct {
    UA_UInt16 id;
    UA_UInt32 positionArrayId;
    UA_UInt32 speedArrayId;
    UA_Double latitude;
    UA_Double longitude;
    UA_Double altitudeAbs;
    UA_Double altitudeRel;
    UA_Int64 timestamp;
    UA_Float  yaw;
    UA_Float  speed;
    UA_Float  climbRate;
    char      message[MAX_MESSAGE_SIZE];
    UA_UInt32 messageId;
} JSDroneData;

typedef struct {
    UA_Double x;
    UA_Double y;
    UA_Double z;
    UA_Int64 timestamp;
} JSPositionData;

typedef struct {
    char*       name;
    char*       typeName;
    UA_NodeId   typeNodeId;
    char*       description;
    void*       value;
    int         type;
    UA_Byte     builtInType;
    UA_Int32    valueRank;
    size_t      arrayDimensionsSize;
    UA_UInt32*  arrayDimensions;
    union {
        void*     (*getArray)(void);
        UA_String (*getString)(void);
    } getter;
} VariableData;

typedef struct {
    size_t nbVariable;
    VariableData *variableArray;
} VariableStruct;

typedef struct {
    VariableStruct variables;
    void          (*init_node_id)(UA_UInt32 id, UA_UInt32 nb, UA_UInt32 magic);
} InstanceData;

int runPubsub(const UA_Logger *logger, UA_String *transportProfile,
              UA_NetworkAddressUrlDataType *networkAddressUrl,
              VariableStruct variables, UA_UInt32 id,
              InstanceData *readerArray, UA_UInt32 nbReader,
              UA_UInt32 maxVariableNb, UA_Duration interval,
              UA_UInt16 (*get_reader_id)(UA_UInt32 nb),
              VariableData (*get_value)(UA_String identifier),
              void (*update)(UA_UInt32 id, const UA_DataValue*, bool print),
              UA_Boolean *running);

UA_String get_message(void);

UA_UInt16 get_drone_id(UA_UInt32 nb);

void init_drone_node_id(UA_UInt32 id, UA_UInt32 nb, UA_UInt32 magic);

void init_subscriber_node_id(UA_UInt32 id, UA_UInt32 nb, UA_UInt32 magic);

VariableData pubsub_get_value(UA_String identifier);

DLL_PUBLIC JSModuleDef *js_init_module(JSContext *ctx, const char *module_name);

#endif /* __PUBSUB_H__ */
